
* Code: https://github.com/gammapy/gammapy
* Docs: https://docs.gammapy.org/

**Gammapy** is an open source (BSD licensed) gamma-ray astronomy Python package.

It is an in-development `affiliated package <http://www.astropy.org/affiliated/index.html>`__ of `Astropy <http://www.astropy.org>`__
that builds on the core `scientific Python stack <http://www.scipy.org/about.html>`__ to provide tools to simulate and analyse
the gamma-ray sky for telescopes such as `CTA <https://www.cta-observatory.org/>`__, `H.E.S.S. <http://www.mpi-hd.mpg.de/hfm/HESS/>`__,
and `Fermi <http://fermi.gsfc.nasa.gov/>`__.

Gammapy is a place for Python-coding gamma-ray astronomers to share their code and collaborate.
Contributions welcome!
